Index: dsp.c
===================================================================
RCS file: /usr/cvsroot/asterisk/dsp.c,v
retrieving revision 1.30
diff -u -r1.30 dsp.c
--- dsp.c	10 Nov 2004 20:20:18 -0000	1.30
+++ dsp.c	11 Nov 2004 04:27:14 -0000
@@ -1174,15 +1174,15 @@
 			if (newstate == dsp->tstate) {
 				dsp->tcount++;
 				if (dsp->tcount == COUNT_THRESH) {
-					if (dsp->tstate == TONE_STATE_BUSY) {
+					if ((dsp->features & DSP_PROGRESS_BUSY) && dsp->tstate == TONE_STATE_BUSY) {
 						res = AST_CONTROL_BUSY;
 						dsp->features &= ~DSP_FEATURE_CALL_PROGRESS;
-					} else if (dsp->tstate == TONE_STATE_TALKING) {
+					} else if ((dsp->features & DSP_PROGRESS_TALK) && dsp->tstate == TONE_STATE_TALKING) {
 						res = AST_CONTROL_ANSWER;
 						dsp->features &= ~DSP_FEATURE_CALL_PROGRESS;
-					} else if (dsp->tstate == TONE_STATE_RINGING)
+					} else if ((dsp->features & DSP_PROGRESS_RINGING) && dsp->tstate == TONE_STATE_RINGING)
 						res = AST_CONTROL_RINGING;
-					else if (dsp->tstate == TONE_STATE_SPECIAL3) {
+					else if ((dsp->features & DSP_PROGRESS_CONGESTION) && dsp->tstate == TONE_STATE_SPECIAL3) {
 						res = AST_CONTROL_CONGESTION;
 						dsp->features &= ~DSP_FEATURE_CALL_PROGRESS;
 					}
@@ -1576,15 +1576,16 @@
 	}
 	if ((dsp->features & DSP_FEATURE_CALL_PROGRESS)) {
 		res = __ast_dsp_call_progress(dsp, shortdata, len);
-		memset(&dsp->f, 0, sizeof(dsp->f));
-		dsp->f.frametype = AST_FRAME_CONTROL;
 		if (res) {
 			switch(res) {
 			case AST_CONTROL_ANSWER:
 			case AST_CONTROL_BUSY:
 			case AST_CONTROL_RINGING:
 			case AST_CONTROL_CONGESTION:
+				memset(&dsp->f, 0, sizeof(dsp->f));
+				dsp->f.frametype = AST_FRAME_CONTROL;
 				dsp->f.subclass = res;
+				dsp->f.src = "dsp_progress";
 				if (chan) 
 					ast_queue_frame(chan, &dsp->f);
 				break;
Index: include/asterisk/dsp.h
===================================================================
RCS file: /usr/cvsroot/asterisk/include/asterisk/dsp.h,v
retrieving revision 1.4
diff -u -r1.4 dsp.h
--- include/asterisk/dsp.h	7 Jun 2004 23:38:39 -0000	1.4
+++ include/asterisk/dsp.h	11 Nov 2004 04:27:16 -0000
@@ -14,11 +14,10 @@
 #ifndef _ASTERISK_DSP_H
 #define _ASTERISK_DSP_H
 
-#define DSP_FEATURE_SILENCE_SUPPRESS (1 << 0)
-#define DSP_FEATURE_BUSY_DETECT      (1 << 1)
-#define DSP_FEATURE_CALL_PROGRESS    (1 << 2)
-#define DSP_FEATURE_DTMF_DETECT		 (1 << 3)
-#define DSP_FEATURE_FAX_DETECT		 (1 << 4)
+#define DSP_FEATURE_SILENCE_SUPPRESS	(1 << 0)
+#define DSP_FEATURE_BUSY_DETECT		(1 << 1)
+#define DSP_FEATURE_DTMF_DETECT		(1 << 3)
+#define DSP_FEATURE_FAX_DETECT		(1 << 4)
 
 #define	DSP_DIGITMODE_DTMF			0				/* Detect DTMF digits */
 #define DSP_DIGITMODE_MF			1				/* Detect MF digits */
@@ -27,6 +26,12 @@
 #define DSP_DIGITMODE_MUTECONF		(1 << 9)		/* Mute conference */
 #define DSP_DIGITMODE_MUTEMAX		(1 << 10)		/* Delay audio by a frame to try to extra quelch */
 #define DSP_DIGITMODE_RELAXDTMF		(1 << 11)		/* "Radio" mode (relaxed DTMF) */
+
+#define DSP_PROGRESS_TALK		(1 << 16)		/* Enable talk detection */
+#define DSP_PROGRESS_RINGING		(1 << 17)		/* Enable calling tone detection */
+#define DSP_PROGRESS_BUSY		(1 << 18)		/* Enable busy tone detection */
+#define DSP_PROGRESS_CONGESTION		(1 << 19)		/* Enable congestion tone detection */
+#define DSP_FEATURE_CALL_PROGRESS	(DSP_PROGRESS_TALK | DSP_PROGRESS_RINGING | DSP_PROGRESS_BUSY | DSP_PROGRESS_CONGESTION)
 
 struct ast_dsp;
 
